pub trait StreamingModule {
// Required methods
fn step(&mut self, xs: &StreamTensor) -> Result<StreamTensor>;
fn reset_state(&mut self);
}Expand description
Streaming modules take as input a stream tensor and return a stream tensor. They may perform some internal buffering so that enough data has been received for the module to be able to perform some operations.
Required Methods
fn step(&mut self, xs: &StreamTensor) -> Result<StreamTensor>
fn reset_state(&mut self)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".